package ch.capi.geom 
{
	import flash.display.Graphics;	
	import flash.geom.Point;
	
	import ch.capi.display.IDrawable;		
	import ch.capi.utils.ICloneable;	
	
	/**
	 * Represents a 2D vector.
	 * 
	 * @author		Cedric Tabin - thecaptain
	 * @version 	1.0
	 */
	public class Vector implements ICloneable, IDrawable
	{
		//---------//
		//Variables//
		//---------//
		
		/**
		 * Defines the x coordinate.
		 */
		public var x:Number;
		
		/**
		 * Defines the y coordinate.
		 */
		public var y:Number;
		
		//-----------------//
		//Getters & Setters//
		//-----------------//
		
		/**
		 * Defines the norm of the <code>Vector</code>. This value cannot be
		 * lower than 0 !
		 */
		public function get norm():Number { return Math.sqrt(x*x+y*y); }
		public function set norm(value:Number):void
		{
			if (value < 0) throw new ArgumentError("value cannot be lower than zero");
			
			normalize();
			scale(value);
		}

		//-----------//
		//Constructor//
		//-----------//
		
		/**
		 * Creates a new <code>Vector</code> object.
		 * 
		 * @param	x	The x coordinate.
		 * @param	y	The y coordinate.
		 */
		public function Vector(x:Number=0, y:Number=0):void
		{
			this.x = x;
			this.y = y;
		}
		
		//--------------//
		//Public methods//
		//--------------//
		
		/**
		 * Scales the current <code>Vector</code>.
		 * 
		 * @param	value	The scale value.
		 */
		public function scale(value:Number):void
		{
			x *= value;
			y *= value;
		}
		
		/**
		 * Adds the specified <code>Vector</code>.
		 * 
		 * @param	value	The <code>Vector</code> to add.
		 */
		public function add(value:Vector):void
		{
			x += value.x;
			y += value.y;
		}
		
		/**
		 * Normalize the <code>Vector</code>. After calling this method, the norm value
		 * will be 1.
		 */
		public function normalize():void
		{
			var cn:Number = norm;
			if (cn == 0 || cn == 1) return;
			
			x /= cn;
			y /= cn;
		}
		
		/**
		 * Creates a copy of the <code>Vector</code>.
		 * 
		 * @return	The copy of the <code>Vector</code>.
		 */
		public function clone():Object 
		{
			return new Vector(x, y);
		}
		
		/**
		 * Retrieves a <code>Point</code> with the same coordinate value than the 
		 * current <code>Vector</code>.
		 * 
		 * @return	The <code>Point</code>.
		 */
		public function toPoint():Point
		{
			return new Point(x, y);
		}
		
		/**
		 * Draws the current <code>IShape</code> to the specified <code>Graphics</code> object.
		 * 
		 * @param	gr	The <code>Graphics</code> object to draw to.
		 */
		public function draw(gr:Graphics):void
		{
			gr.lineTo(x, y);
		}
	}
}
